==> cinemaru-1.4.zip: cinemaru/language/japanese/main.php <==
<?php
//%%%%%%	Module Name 'cinemaru'		  %%%%%
define("_XD_TITLE","CINEMARU");

define("_MD_CINEMARU_MOVIE_UPLOAD", "ư/MP3åץ");
define("_MD_CINEMARU_TITLE", "ȥ");
define("_MD_CINEMARU_MOVIE_FILE", "ư/MP3ե");
define("_MD_CINEMARU_FLV_ONLY", "FLV/MP3եΤ");
define("_MD_CINEMARU_THUMB_FILE", "ͥ");
define("_MD_CINEMARU_DESC", "");
define("_MD_CINEMARU_GENRE", "");
define("_MD_CINEMARU_MOVIE_EDIT", "ưԽ");
define('_MD_CINEMARU_MOVIE_DELETE', 'ư');
define("_MD_CINEMARU_TAG_LOCK", "å");
define("_MD_CINEMARU_TAG_LOCK_DESC", "å");
define("_MD_CINEMARU_USER", "Ƽ");
define("_MD_CINEMARU_SUBMIT", "Ƥ");

define('_MD_CINEMARU_ERROR_NO_DATA', '%s ϤƤ');
define('_MD_CINEMARU_ERROR_MAIL_NG_FORMAT', '%s ϤǤ');
define('_MD_CINEMARU_ERROR_URL_NG_FORMAT', '%s ϤǤ');
define('_MD_CINEMARU_ERROR_SIZE_OVER', '%s Ⱦ %s ʸϤƤ');
define('_MD_CINEMARU_ERROR_SIZE_UNDER', '%s Ⱦ %s ʸʾϤƤ');
define('_MD_CINEMARU_ERROR_CONFIRM_NO_MATCH', '%s פޤǤ');
define('_MD_CINEMARU_ERROR_MAIL_EXISTS', '᡼륢ɥ쥹ϿѤߤǤ');
define('_MD_CINEMARU_ERROR_MAIL_NO_EXISTS', '᡼륢ɥ쥹ϿƤޤǤ');
define('_MD_CINEMARU_ERROR_NO_AUTH', '᡼륢ɥ쥹ޤϥѥɤ㤤ޤ');
define('_MD_CINEMARU_ERROR_NO_PASSWORD', 'ѥɤ㤤ޤ');
define('_MD_CINEMARU_ERROR_NO_IMAGE_FILE', '%s ϲեǤϤޤ');
define('_MD_CINEMARU_ERROR_NO_FLV_FILE', '%s FLVեǤϤޤ');
define('_MD_CINEMARU_ERROR_NG_FILE_UPLOAD', '%s ϥեΥåץɤ˼Ԥޤ');
define('_MD_CINEMARU_ERROR_NO_FILE', '%s ˥եꤷƤ');

define('_MD_CINEMARU_ERROR_UPLOAD_ERR_INI_SIZE', 'ե륵¤ۤޤ(UPLOAD_ERR_INI_SIZE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_FORM_SIZE', 'ե륵¤ۤޤ(UPLOAD_ERR_FORM_SIZE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_PARTIAL', 'åץɤ˼Ԥޤ(UPLOAD_ERR_PARTIAL)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_NO_FILE', 'åץɤ˼Ԥޤ(UPLOAD_ERR_NO_FILE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_NO_TMP_DIR', 'åץɤ˼Ԥޤ(UPLOAD_ERR_NO_TMP_DIR)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_CANT_WRITE', 'åץɤ˼Ԥޤ(UPLOAD_ERR_CANT_WRITE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_EXTENSION', 'åץɤ˼Ԥޤ(UPLOAD_ERR_EXTENSION)');

define('_MD_CINEMARU_ERROR_NO_TITLE', 'ȥϤƤ');
define('_MD_CINEMARU_ERROR_DESC_OVER', '1000ʸޤǤǤ');
define('_MD_CINEMARU_COUNT', '');
define('_MD_CINEMARU_COMMENT', '');
define('_MD_CINEMARU_EDIT', 'Խ');
define('_MD_CINEMARU_DELETE', '');
define('_MD_CINEMARU_ADD', 'ɲ');
define('_MD_CINEMARU_UPLOAD', 'åץ');
define('_MD_CINEMARU_UPDATE', '');

define('_MD_CINEMARU_MOVIE_NOT_FOUND', 'ư褬ĤޤǤ');
define('_MD_CINEMARU_UPDATED', 'ޤ');
define('_MD_CINEMARU_DELETED', 'ޤ');
define('_MD_CINEMARU_THANKSSUBMIT', 'Ƥ꤬Ȥޤ');

define('_MD_CINEMARU_TAG', '');
define('_MD_CINEMARU_EDIT_TAG', 'Խ');
define('_MD_CINEMARU_END_EDIT_TAG', 'Խλ');

define('_MD_CINEMARU_NO_REG_AUTH', 'Ƹ¤ޤ');
define('_MD_CINEMARU_NO_DEL_AUTH', '¤ޤ');
define('_MD_CINEMARU_NO_EDIT_AUTH', 'Խ¤ޤ');
define('_MD_CINEMARU_NO_VALID_AUTH', 'ǧ¤ޤ');
define('_MD_CINEMARU_NO_REPORT_AUTH', 'ȿ𸢸¤ޤ');
define('_MD_CINEMARU_NO_REPORT_LIST_AUTH', 'ȿꥹȱ¤ޤ');

define('_MD_CINEMARU_NEXT', '');
define('_MD_CINEMARU_PREV', '');

define('_MD_CINEMARU_TOTAL', '׷');

define('_MD_CINEMARU_MOVIE_NO_VALID', 'ưϾǧԤǤ');
define('_MD_CINEMARU_MOVIE_NO_VALID2', '̤ǧ');
define('_MD_CINEMARU_MOVIE_NO_VALID3', '̤ǧˤ');
define('_MD_CINEMARU_MOVIE_VALID', 'ǧ');
define('_MD_CINEMARU_MOVIE_VALIDED', 'ǧޤ');
define('_MD_CINEMARU_MOVIE_NG_VALIDED', '̤ǧޤ');

define('_MD_CINEMARU_MOVIE_LIST_NO_VALID', '̤ǧưΤɽ');
define('_MD_CINEMARU_MOVIE_LIST_NO_VALID_EXISTS', '̤ǧư褬ޤ');
define('_MD_CINEMARU_MOVIE_LIST_NORMAL', '̾ɽ');

define('_MD_CINEMARU_MOVIE', 'ư');
define('_MD_CINEMARU_TIME', '');
define('_MD_CINEMARU_ACTION', '');

define('_MD_CINEMARU_NO_COMMENT_READ', 'ȱ¤ޤ');
define('_MD_CINEMARU_NO_DELETE_COMMENT_ADMIN', 'Ⱥ¤ޤ');
define('_MD_CINEMARU_DELETED_COMMENT', 'Ȥޤ');
define('_MD_CINEMARU_COMMENT_ADMIN', 'ȴ');
define('_MD_CINEMARU_COMMENT_LIST', 'Ȱ');
define('_MD_CINEMARU_COMMENT_TIME', 'ɽ');

define('_MD_CINEMARU_LIST', 'ꥹɽ');
define('_MD_CINEMARU_THUMB', 'ͥɽ');

define('_MD_CINEMARU_WAIT_VALID', 'ư/MP3Ͼǧ塢Ǥ褦ˤʤޤ');

define('_MD_CINEMARU_SORT', '');
define('_MD_CINEMARU_SORT_NEW', 'Ͽ');
define('_MD_CINEMARU_SORT_OLD', 'ϿŤ');
define('_MD_CINEMARU_SORT_HIGH_HIT', '¿');
define('_MD_CINEMARU_SORT_LOW_HIT', 'ʤ');

define('_MD_CINEMARU_VIOLATION_REPORT_LIST', 'ȿ/ڤꥹ');
define('_MD_CINEMARU_VIOLATION_REPORT', 'ȿ/ڤ򤹤');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT', 'ƥ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_1', 'ڤ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_2', 'åץ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_3', 'Ūɽ˽ɽ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_4', '¾');

define('_MD_CINEMARU_REPORTED', '𤷤ޤ');
define('_MD_CINEMARU_DELETED_REPORT', 'ޤ');
define('_MD_CINEMARU_CHECK_REPORT_LIST', 'ȿ/ڤ𤬤ޤ');

define('_MD_CINEMARU_FILE_UPLOAD', 'ե륢åץ');
define('_MD_CINEMARU_URL', 'URL');
define('_MD_CINEMARU_FILE_URL', 'եURL');
define('_MD_CINEMARU_IMAGE_FILE_UPLOAD', 'ե륢åץ');
define('_MD_CINEMARU_IMAGE_FILE_URL', 'եURL');

define('_MD_CINEMARU_BLOG_PASTE_TAG', '֥Žդѥ');

define('_MD_CINEMARU_URL_DESC', 'FLV/MP3եؤURLꤷƤ<br />YouTubeξ http://???.youtube.com/watch?v=xxxxxxxxxxx ηǻꤷƤ ');

==> cinemaru-1.7.zip: cinemaru/language/japanese/main.php <==
<?php

if (defined('__CINEMARU_MAIN_PHP__')) {
    return;
}
define('__CINEMARU_MAIN_PHP__', 1);

define("_MD_CINEMARU_MOVIE_UPLOAD", "ư/MP3åץ");
define("_MD_CINEMARU_TITLE", "ȥ");
define("_MD_CINEMARU_MOVIE_FILE", "ư/MP3ե");
define("_MD_CINEMARU_FLV_ONLY", "FLV/MP3եΤ");
define("_MD_CINEMARU_THUMB_FILE", "ͥ");
define("_MD_CINEMARU_DESC", "");
define("_MD_CINEMARU_GENRE", "");
define("_MD_CINEMARU_MOVIE_EDIT", "ưԽ");
define('_MD_CINEMARU_MOVIE_DELETE', 'ư');
define("_MD_CINEMARU_TAG_LOCK", "å");
define("_MD_CINEMARU_TAG_LOCK_DESC", "å");
define("_MD_CINEMARU_USER", "Ƽ");
define("_MD_CINEMARU_SUBMIT", "Ƥ");

define('_MD_CINEMARU_ERROR_NO_DATA', '%s ϤƤ');
define('_MD_CINEMARU_ERROR_MAIL_NG_FORMAT', '%s ϤǤ');
define('_MD_CINEMARU_ERROR_URL_NG_FORMAT', '%s ϤǤ');
define('_MD_CINEMARU_ERROR_SIZE_OVER', '%s Ⱦ %s ʸϤƤ');
define('_MD_CINEMARU_ERROR_SIZE_UNDER', '%s Ⱦ %s ʸʾϤƤ');
define('_MD_CINEMARU_ERROR_CONFIRM_NO_MATCH', '%s פޤǤ');
define('_MD_CINEMARU_ERROR_MAIL_EXISTS', '᡼륢ɥ쥹ϿѤߤǤ');
define('_MD_CINEMARU_ERROR_MAIL_NO_EXISTS', '᡼륢ɥ쥹ϿƤޤǤ');
define('_MD_CINEMARU_ERROR_NO_AUTH', '᡼륢ɥ쥹ޤϥѥɤ㤤ޤ');
define('_MD_CINEMARU_ERROR_NO_PASSWORD', 'ѥɤ㤤ޤ');
define('_MD_CINEMARU_ERROR_NO_IMAGE_FILE', '%s ϲեǤϤޤ');
define('_MD_CINEMARU_ERROR_NO_FLV_FILE', '%s FLVեǤϤޤ');
define('_MD_CINEMARU_ERROR_NG_FILE_UPLOAD', '%s ϥեΥåץɤ˼Ԥޤ');
define('_MD_CINEMARU_ERROR_NO_FILE', '%s ˥եꤷƤ');

define('_MD_CINEMARU_ERROR_UPLOAD_ERR_INI_SIZE', 'ե륵¤ۤޤ(UPLOAD_ERR_INI_SIZE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_FORM_SIZE', 'ե륵¤ۤޤ(UPLOAD_ERR_FORM_SIZE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_PARTIAL', 'åץɤ˼Ԥޤ(UPLOAD_ERR_PARTIAL)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_NO_FILE', 'åץɤ˼Ԥޤ(UPLOAD_ERR_NO_FILE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_NO_TMP_DIR', 'åץɤ˼Ԥޤ(UPLOAD_ERR_NO_TMP_DIR)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_CANT_WRITE', 'åץɤ˼Ԥޤ(UPLOAD_ERR_CANT_WRITE)');
define('_MD_CINEMARU_ERROR_UPLOAD_ERR_EXTENSION', 'åץɤ˼Ԥޤ(UPLOAD_ERR_EXTENSION)');

define('_MD_CINEMARU_ERROR_NO_TITLE', 'ȥϤƤ');
define('_MD_CINEMARU_ERROR_DESC_OVER', '1000ʸޤǤǤ');
define('_MD_CINEMARU_COUNT', '');
define('_MD_CINEMARU_COMMENT', '');
define('_MD_CINEMARU_EDIT', 'Խ');
define('_MD_CINEMARU_DELETE', '');
define('_MD_CINEMARU_ADD', 'ɲ');
define('_MD_CINEMARU_UPLOAD', 'åץ');
define('_MD_CINEMARU_UPDATE', '');

define('_MD_CINEMARU_MOVIE_NOT_FOUND', 'ư褬ĤޤǤ');
define('_MD_CINEMARU_UPDATED', 'ޤ');
define('_MD_CINEMARU_DELETED', 'ޤ');
define('_MD_CINEMARU_THANKSSUBMIT', 'Ƥ꤬Ȥޤ');

define('_MD_CINEMARU_TAG', '');
define('_MD_CINEMARU_EDIT_TAG', 'Խ');
define('_MD_CINEMARU_END_EDIT_TAG', 'Խλ');

define('_MD_CINEMARU_NO_REG_AUTH', 'Ƹ¤ޤ');
define('_MD_CINEMARU_NO_DEL_AUTH', '¤ޤ');
define('_MD_CINEMARU_NO_EDIT_AUTH', 'Խ¤ޤ');
define('_MD_CINEMARU_NO_VALID_AUTH', 'ǧ¤ޤ');
define('_MD_CINEMARU_NO_REPORT_AUTH', 'ȿ𸢸¤ޤ');
define('_MD_CINEMARU_NO_REPORT_LIST_AUTH', 'ȿꥹȱ¤ޤ');

define('_MD_CINEMARU_NEXT', '');
define('_MD_CINEMARU_PREV', '');

define('_MD_CINEMARU_TOTAL', '׷');

define('_MD_CINEMARU_MOVIE_NO_VALID', 'ưϾǧԤǤ');
define('_MD_CINEMARU_MOVIE_NO_VALID2', '̤ǧ');
define('_MD_CINEMARU_MOVIE_NO_VALID3', '̤ǧˤ');
define('_MD_CINEMARU_MOVIE_VALID', 'ǧ');
define('_MD_CINEMARU_MOVIE_VALIDED', 'ǧޤ');
define('_MD_CINEMARU_MOVIE_NG_VALIDED', '̤ǧޤ');

define('_MD_CINEMARU_MOVIE_LIST_NO_VALID', '̤ǧưΤɽ');
define('_MD_CINEMARU_MOVIE_LIST_NO_VALID_EXISTS', '̤ǧư褬ޤ');
define('_MD_CINEMARU_MOVIE_LIST_NORMAL', '̾ɽ');

define('_MD_CINEMARU_MOVIE', 'ư');
define('_MD_CINEMARU_TIME', '');
define('_MD_CINEMARU_ACTION', '');

define('_MD_CINEMARU_NO_COMMENT_READ', 'ȱ¤ޤ');
define('_MD_CINEMARU_NO_DELETE_COMMENT_ADMIN', 'Ⱥ¤ޤ');
define('_MD_CINEMARU_DELETED_COMMENT', 'Ȥޤ');
define('_MD_CINEMARU_COMMENT_ADMIN', 'ȴ');
define('_MD_CINEMARU_COMMENT_LIST', 'Ȱ');
define('_MD_CINEMARU_COMMENT_TIME', 'ɽ');

define('_MD_CINEMARU_LIST', 'ꥹɽ');
define('_MD_CINEMARU_THUMB', 'ͥɽ');

define('_MD_CINEMARU_WAIT_VALID', 'ư/MP3Ͼǧ塢Ǥ褦ˤʤޤ');

define('_MD_CINEMARU_SORT', '');
define('_MD_CINEMARU_SORT_NEW', 'Ͽ');
define('_MD_CINEMARU_SORT_OLD', 'ϿŤ');
define('_MD_CINEMARU_SORT_HIGH_HIT', '¿');
define('_MD_CINEMARU_SORT_LOW_HIT', 'ʤ');

define('_MD_CINEMARU_VIOLATION_REPORT_LIST', 'ȿ/ڤꥹ');
define('_MD_CINEMARU_VIOLATION_REPORT', 'ȿ/ڤ򤹤');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT', 'ƥ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_1', 'ڤ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_2', 'åץ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_3', 'Ūɽ˽ɽ');
define('_MD_CINEMARU_VIOLATION_REPORT_CAT_4', '¾');

define('_MD_CINEMARU_REPORTED', '𤷤ޤ');
define('_MD_CINEMARU_DELETED_REPORT', 'ޤ');
define('_MD_CINEMARU_CHECK_REPORT_LIST', 'ȿ/ڤ𤬤ޤ');

define('_MD_CINEMARU_FILE_UPLOAD', 'ե륢åץ');
define('_MD_CINEMARU_URL', 'URL');
define('_MD_CINEMARU_FILE_URL', 'եURL');
define('_MD_CINEMARU_IMAGE_FILE_UPLOAD', 'ե륢åץ');
define('_MD_CINEMARU_IMAGE_FILE_URL', 'եURL');

define('_MD_CINEMARU_BLOG_PASTE_TAG', '֥Žդѥ');

define('_MD_CINEMARU_URL_DESC', 'FLV/MP3եؤURLꤷƤ<br />YouTubeξ http://???.youtube.com/watch?v=xxxxxxxxxxx ηǻꤷƤ ');
